ApiException class

Base class for all API exceptions.

Implemented types
Implementers

Constructors

ApiException({required String message, int? statusCode, dynamic data})
Creates a new ApiException.

Properties

data → dynamic
The raw response data, if available.
final
hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable error message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
The HTTP status code, if available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited