AuthInterceptor class

A professional interceptor to handle authentication via Bearer tokens.

Features:

  • Automatic token injection into headers.
  • Flexible token retrieval via tokenProvider.
  • Exclusion of specific paths (e.g., login, register).
Inheritance

Constructors

AuthInterceptor({required Future<String?> tokenProvider(), List<String>? excludePaths, String authPrefix = 'Bearer', String headerKey = 'Authorization'})
Creates an AuthInterceptor.

Properties

authPrefix String
Format of the Authorization header prefix. Defaults to "Bearer".
final
excludePaths List<String>?
Optional list of paths that do NOT require authentication.
final
hashCode int
The hash code for this object.
no setterinherited
headerKey String
The header key to use. Defaults to "Authorization".
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenProvider Future<String?> Function()
Callback to retrieve the authentication token.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(DioException err, ErrorInterceptorHandler handler) → void
Called when an exception was occurred during the request.
inherited
onRequest(RequestOptions options, RequestInterceptorHandler handler) Future<void>
Called when the request is about to be sent.
override
onResponse(Response response, ResponseInterceptorHandler handler) → void
Called when the response is about to be resolved.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited