dio_logger_interceptor library

Classes

LoggerInterceptor
An interceptor that logs the requests and responses in a readable format.

Enums

Level
Levels of logging for the API services.

Functions

logDebug(String message, {Level level = Level.info}) → void
A global function to log messages at specified specified Level.