LoggerInterceptor class

An interceptor that logs the requests and responses in a readable format.

Inheritance

Constructors

LoggerInterceptor({bool logRequestUrl = true, bool logRequestHeader = false, bool logRequestBody = false, bool logResponseHeader = false, bool logResponseBody = true, bool logResponseError = true})
Creates a LoggerInterceptor with configurable logging options.

Properties

hashCode int
The hash code for this object.
no setterinherited
logRequestBody bool
Whether to print the request body.
final
logRequestHeader bool
Whether to print the request headers.
final
logRequestUrl bool
Whether to print the request URL.
final
logResponseBody bool
Whether to print the response body.
final
logResponseError bool
Whether to print error messages.
final
logResponseHeader bool
Whether to print the response headers.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(DioException err, ErrorInterceptorHandler handler) → void
Called when an exception was occurred during the request.
override
onRequest(RequestOptions options, RequestInterceptorHandler handler) → void
Called when the request is about to be sent.
override
onResponse(Response response, ResponseInterceptorHandler handler) → void
Called when the response is about to be resolved.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited