RetryNotSupportedException class

Exception thrown when a retry operation is not supported for the given request.

Implemented types

Constructors

RetryNotSupportedException([String? message])
Creates a RetryNotSupportedException with an optional message.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String?
Error message explaining why the retry is not supported.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited