NoInternetException class
Thrown when there is no internet connection.
- Inheritance
-
- Object
- ApiException
- NoInternetException
Constructors
- NoInternetException()
- Creates a new NoInternetException.
Properties
- data → dynamic
-
The raw response data, if available.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A human-readable error message.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int?
-
The HTTP status code, if available.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited