menu
dio_api_services package
documentation
dio_logger_interceptor.dart
dio_logger_interceptor.dart
dark_mode
light_mode
dio_logger_interceptor
library
Classes
LoggerInterceptor
An interceptor that logs the requests and responses in a readable format.
Enums
Level
Levels of logging for the API services.
Functions
logDebug
(
String
message
, {
Level
level
=
Level.info
})
→ void
A global function to log messages at specified specified
Level
.
dio_api_services package
documentation
dio_logger_interceptor.dart
dio_api_services
package
Libraries
api_exception
auth_interceptor
connectivity_status
dio_api_services
dio_error_util
dio_logger_interceptor
smart_retry/default_retry_evaluator
smart_retry/http_status_codes
smart_retry/multipart_file_recreatable
smart_retry/retry_interceptor
smart_retry/retry_not_supported_exception
dio_logger_interceptor library