smart_retry/http_status_codes library
Constants
-
defaultRetryableStatuses
→ const Set<
int> - Set of HTTP status codes that are considered retryable by default.
-
retryableStatuses
→ const Set<
int> - Deprecated version of defaultRetryableStatuses.
- status100Continue → const int
- HTTP 100 Continue
- status101SwitchingProtocols → const int
- HTTP 101 Switching Protocols
- status102Processing → const int
- HTTP 102 Processing
- status200OK → const int
- HTTP 200 OK
- status201Created → const int
- HTTP 201 Created
- status202Accepted → const int
- HTTP 202 Accepted
- status203NonAuthoritative → const int
- HTTP 203 Non-Authoritative Information
- status204NoContent → const int
- HTTP 204 No Content
- status205ResetContent → const int
- HTTP 205 Reset Content
- status206PartialContent → const int
- HTTP 206 Partial Content
- status207Multistatus → const int
- HTTP 207 Multi-Status
- status208AlreadyReported → const int
- HTTP 208 Already Reported
- status226IMUsed → const int
- HTTP 226 IM Used
- status300MultipleChoices → const int
- HTTP 300 Multiple Choices
- status301MovedPermanently → const int
- HTTP 301 Moved Permanently
- status302Found → const int
- HTTP 302 Found
- status303SeeOther → const int
- HTTP 303 See Other
- status304NotModified → const int
- HTTP 304 Not Modified
- status305UseProxy → const int
- HTTP 305 Use Proxy
- status306SwitchProxy → const int
- HTTP 306 Switch Proxy
- status307TemporaryRedirect → const int
- HTTP 307 Temporary Redirect
- status308PermanentRedirect → const int
- HTTP 308 Permanent Redirect
- status400BadRequest → const int
- HTTP 400 Bad Request
- HTTP 401 Unauthorized
- status402PaymentRequired → const int
- HTTP 402 Payment Required
- status403Forbidden → const int
- HTTP 403 Forbidden
- status404NotFound → const int
- HTTP 404 Not Found
- status405MethodNotAllowed → const int
- HTTP 405 Method Not Allowed
- status406NotAcceptable → const int
- HTTP 406 Not Acceptable
- status407ProxyAuthenticationRequired → const int
- HTTP 407 Proxy Authentication Required
- status408RequestTimeout → const int
- HTTP 408 Request Timeout
- status409Conflict → const int
- HTTP 409 Conflict
- status410Gone → const int
- HTTP 410 Gone
- status411LengthRequired → const int
- HTTP 411 Length Required
- status412PreconditionFailed → const int
- HTTP 412 Precondition Failed
- status413PayloadTooLarge → const int
- HTTP 413 Payload Too Large (RFC 7231)
- status413RequestEntityTooLarge → const int
- HTTP 413 Request Entity Too Large (RFC 2616)
- status414RequestUriTooLong → const int
- HTTP 414 Request-URI Too Long (RFC 2616)
- status414UriTooLong → const int
- HTTP 414 URI Too Long (RFC 7231)
- status415UnsupportedMediaType → const int
- HTTP 415 Unsupported Media Type
- status416RangeNotSatisfiable → const int
- HTTP 416 Range Not Satisfiable (RFC 7233)
- status416RequestedRangeNotSatisfiable → const int
- HTTP 416 Requested Range Not Satisfiable (RFC 2616)
- status417ExpectationFailed → const int
- HTTP 417 Expectation Failed
- status418ImATeapot → const int
- HTTP 418 I'm a teapot
- status419AuthenticationTimeout → const int
- HTTP 419 Authentication Timeout
- status421MisdirectedRequest → const int
- HTTP 421 Misdirected Request
- status422UnprocessableEntity → const int
- HTTP 422 Unprocessable Entity
- status423Locked → const int
- HTTP 423 Locked
- status424FailedDependency → const int
- HTTP 424 Failed Dependency
- status424UpgradeRequired → const int
- HTTP 426 Upgrade Required
- status428PreconditionRequired → const int
- HTTP 428 Precondition Required
- status429TooManyRequests → const int
- HTTP 429 Too Many Requests
- status431RequestHeaderFieldsTooLarge → const int
- HTTP 431 Request Header Fields Too Large
- status440LoginTimeout → const int
- IIS: Login Timeout
- HTTP 451 Unavailable For Legal Reasons
- status460ClientClosedRequest → const int
- AWS ELB: Client Closed Request
- status499ClientClosedRequest → const int
- Nginx: Client Closed Request
- status500InternalServerError → const int
- HTTP 500 Internal Server Error
- status501NotImplemented → const int
- HTTP 501 Not Implemented
- status502BadGateway → const int
- HTTP 502 Bad Gateway
- HTTP 503 Service Unavailable
- status504GatewayTimeout → const int
- HTTP 504 Gateway Timeout
- status505HttpVersionNotSupported → const int
- HTTP 505 HTTP Version Not Supported
- status506VariantAlsoNegotiates → const int
- HTTP 506 Variant Also Negotiates
- status507InsufficientStorage → const int
- HTTP 507 Insufficient Storage
- status508LoopDetected → const int
- HTTP 508 Loop Detected
- status510NotExtended → const int
- HTTP 510 Not Extended
- status511NetworkAuthenticationRequired → const int
- HTTP 511 Network Authentication Required
- status520WebServerReturnedUnknownError → const int
- Cloudflare: Web Server Returned Unknown Error
- status521WebServerIsDown → const int
- Cloudflare: Web Server Is Down
- status522ConnectionTimedOut → const int
- Cloudflare: Connection Timed Out
- status523OriginIsUnreachable → const int
- Cloudflare: Origin Is Unreachable
- status524TimeoutOccurred → const int
- Cloudflare: Timeout Occurred
- status525SSLHandshakeFailed → const int
- Cloudflare: SSL Handshake Failed
- status526InvalidSSLCertificate → const int
- Cloudflare: Invalid SSL Certificate
- status527RailgunError → const int
- Cloudflare: Railgun Error
- status598NetworkReadTimeoutError → const int
- Network Read Timeout Error (Not in RFC)
- status599NetworkConnectTimeoutError → const int
- Network Connect Timeout Error (Not in RFC)
Functions
-
isRetryable(
int statusCode) → bool - Utility function to check if a status code is in the default retryable list.